# bay-lang-python

Bay Lang for python3

Coming soon. Arrival 2024, or later...

Python version: https://github.com/bayrell/bay-lang-python

NodeJS version: https://github.com/bayrell/bay-lang-nodejs
